# Contributors

The following individuals have contributed to Haliax:

- David Hall <dlwh@stanford.edu>
- David Hall <dlwh@cs.stanford.edu>
- Jason Wang <blahblahj.wsy@gmail.com>
- Ivan Zhou <ivan.zhouyq@gmail.com>
- rohan-mehta-1024 <69774557+rohan-mehta-1024@users.noreply.github.com>
- Gary Miguel <garymm@garymm.org>
- Jennifer Zhou <jennifer@jezh.me>
- Joseph Camacho <camacho.joseph@gmail.com>
- Omead Pooladzandi <opooladz@ucla.edu>
- Patrick Kidger <33688385+patrick-kidger@users.noreply.github.com>
- Russell Power <russell.power@gmail.com>
